==> ScriptDeploy-0.4.tar: ScriptDeploy-0.4/action.save_manualassignment.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/Cars/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

	if (!isset($gCms)) exit;
	global $gCms;
	$config =& $gCms->GetConfig(); 
	if(isset($params['cancel'])){
		$params = array('tab_message'=> 'Canceled', 'active_tab' => 'manualassignment');
		$this->Redirect($id, 'defaultadmin', '', $params);
	}
	if(is_numeric($params['group'])){
		$Gid=$params['group'];
		$GroupID=$params['group'];
	}else{
		$Gid=$params['GrouptSet'];
		$GroupID=$params['GrouptSet'];
		}
	$db =& $this->GetDb();
		
	foreach($params as $key => $paramsItem){
		$this->FireDebug('error',"params ".$key." : ".$paramsItem);//<<<<------Fire PHP message	
	}
	$ScriptORDER=$params['ScriptORDER'];
	if(isset($params['REORDER'])){
		$params['mode']='edit';
		$this->FireDebug('error', $Gid);//<<<<------Fire PHP message
		foreach($params['ScriptORDER'] as $key => $ScriptORDER){
			$this->FireDebug('error',"params ".$key." : ".$ScriptORDER);//<<<<------Fire PHP message	
			$ScriptID=$key;
			$this->FireDebug('error', $ScriptID);//<<<<------Fire PHP message
			$this->FireDebug('error', $ScriptORDER);//<<<<------Fire PHP message
			$query = "UPDATE ".cms_db_prefix()."module_scriptdeploy_groupassignment SET ScriptORDER=? WHERE ScriptID= ? AND GrouptSetID=?";
	
			$result = &$db->Execute($query,array($ScriptORDER,$ScriptID,$Gid));
			$db->sql;
			if(!$result){
			  //echo 'Error: '.mysql_error();
			  $params['message'] = mysql_error();
			  $this->FireDebug('error',mysql_error());//<<<<------Fire PHP message
			}else{
			   $params['message'] = $this->Lang('prefsupdated');
			}
		}		
		$this->Redirect($id, 'editassignment', '', $params);
	}
	


		
	//$scriptSize=mb_strlen($_POST['m1_ScriptIs_input'], '8bit');
	$scriptSize=strlen(utf8_decode($params['ScriptIs_input']));
	$GroupName=$params['GrouptSet'];
	
	$ScriptID=$params['ScriptPicker'];
	$GrouptType=$params['GrouptType'];
	
	
	$this->FireDebug('message','$GroupID : '.$GroupID);//<<<<------Fire PHP message	
	$this->FireDebug('message','$ScriptID : '.$ScriptID);//<<<<------Fire PHP message	
	$this->FireDebug('message','$GrouptType : '.$GrouptType);//<<<<------Fire PHP message	
	$this->FireDebug('message','$GroupName : '.$GroupName);//<<<<------Fire PHP message
	$this->FireDebug('message','$scriptSize : '.$scriptSize);//<<<<------Fire PHP message

	if($params['mode']=='add'){
			$query = "INSERT INTO ".cms_db_prefix()."module_scriptdeploy_group SET GrouptSet=?, GrouptType=?";
			$result = &$db->Execute($query,array($GroupName,$GrouptType));
			if(!$result){
			  //echo 'Error: '.mysql_error();
			  $params['message'] = mysql_error();
			}else{
			   $params['message'] = $this->Lang('prefsupdated');
			}
	}else if($params['mode']=='edit'){
			$query = "DELETE sn FROM ".cms_db_prefix()."module_scriptdeploy_groupassignment AS sn WHERE sn.GrouptSetID = ?";
			$result = $db->Execute($query,array($GroupID));
			
			$this->FireDebug('error',$params['message']);//<<<<------Fire PHP message	
			 foreach($ScriptID as $key => $SArrayItem){
				$query = "INSERT INTO ".cms_db_prefix()."module_scriptdeploy_groupassignment (GrouptSetID, ScriptID, ScriptORDER) VALUES ( ?,?,?)";
				$result = &$db->Execute($query,array($GroupID,$SArrayItem,$ScriptORDER));
				if(!$result){
				  //echo 'Error: '.mysql_error();
				  $params['message'] = mysql_error();
				}else{
				   $params['message'] = $this->Lang('prefsupdated');
				}
				$this->FireDebug('error',".GroupName....scriptID. ".$GroupName.",".$scriptID."");//<<<<------Fire PHP message			
			}
			$this->FireDebug('message','echo:---------------'.$srt);//<<<<------Fire PHP message
	}else if($params['mode']=='addScript'){	
		 
		$query = "UPDATE ".cms_db_prefix()."module_scriptdeploy_group AS sdG "
				."INNER join  ".cms_db_prefix()."module_scriptdeploy_scriptoptions so ON sn.ID = so.ID "
				."INNER join  ".cms_db_prefix()."module_scriptdeploy_scriptparts sp ON sn.ID = sp.ID "
				."SET so.Minify=?, sn.ScriptSet=?, so.maxAge=?, so.pathOption=?, so.scriptType=?, sp.ScriptIs=?, so.scriptSize=? WHERE sn.ID = ?";

		$result = &$db->Execute($query,array($Minify,$scriptName,$maxAge,$pathOption,$scriptType,$ScriptIs,$scriptSize,$ScriptID));
		if(!$result){
		  //echo 'Error: '.mysql_error();
		  $params['message'] = mysql_error();
		  $this->FireDebug('error',mysql_error());//<<<<------Fire PHP message
		}else{
		   $params['message'] = $this->Lang('prefsupdated');
		}
		$this->FireDebug('error',$params['mode']);//<<<<------Fire PHP message
	}

	if((isset($params['submitbutton'])&&($params['submitbutton']=='Add')&&($params['Save']!='Save'))){
		$params['mode']='edit';
		$params['GrouptSet']=$params['GrouptSet'];
		$dirpath=$config['uploads_path']."/lib/SD-temp/";
		$deleted = $this->recursive_rmdir($dirpath);
		$this->Redirect($id, 'editassignment', '', $params);
	}
	
	if($params['mode']=='add'){
		$params = array('tab_message'=> 'BtnADDED', 'active_tab' => 'manualassignment');
	}else{
		$params = array('tab_message'=> 'BtnEDITED', 'active_tab' => 'manualassignment');
	}
	
		$dirpath=$config['uploads_path']."/lib/SD-temp/";
		$deleted = $this->recursive_rmdir($dirpath);
	$this->Redirect($id, 'defaultadmin', '', $params);
?>

==> ScriptDeploy-0.5.tar: ScriptDeploy-0.5/action.save_manualassignment.php <==
<?php
#-------------------------------------------------------------------------
# Module: ScriptDeploy - Minify and deployment of JS CSS and HTML 
# Mod designed by jeremyBass (jeremyBass@cableone.net)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/Cars/
#-------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#-------------------------------------------------------------------------

	if (!isset($gCms)) exit;
	global $gCms;
	$config =& $gCms->GetConfig(); 
	if(isset($params['cancel'])){
		$params = array('tab_message'=> 'Canceled', 'active_tab' => 'manualassignment');
		$this->Redirect($id, 'defaultadmin', '', $params);
	}

	$db =& $this->GetDb();
//	if(isset($params['group'])){
//		if(is_numeric($params['group'])){
//			$Gid=$params['group'];
//			$GroupID=$params['group'];
//		}else{
//			$Gid=$params['GrouptSet'];
//			$GroupID=$params['GrouptSet'];
//		}
//	}else{
//		$Gid=$params['GrouptSet'];
//		$GroupID=$params['GrouptSet'];
//	}
	if($params['mode']=='add'){
			$GroupName=$params['GrouptSet'];
			$GrouptType=$params['GrouptType'];
			$query = "INSERT INTO ".cms_db_prefix()."module_scriptdeploy_group SET GrouptSet=?, GrouptType=?";
			$result = &$db->Execute($query,array($GroupName,$GrouptType));
			if(!$result){
			  //echo 'Error: '.mysql_error();
			  $params['message'] = mysql_error();
			}else{
			   $params['message'] = $this->Lang('prefsupdated');
			}
			$Gid=$this->GetGroupID($GroupName);
	}
	$GrouptSet=$params['GrouptSet'];
	$Gid=$this->GetGroupID($GrouptSet);
	foreach($params as $key => $paramsItem){
		$this->FireDebug('error',"params ".$key." : ".$paramsItem);//<<<<------Fire PHP message	
	}
	
	if(isset($params['REORDER'])){
		foreach($params['ScriptORDER'] as $key => $ScriptORDER){
			$this->FireDebug('error',"params ".$key." : ".$ScriptORDER);//<<<<------Fire PHP message	
			$ScriptID=$key;
			$this->FireDebug('error', $ScriptID);//<<<<------Fire PHP message
			$this->FireDebug('error', $ScriptORDER);//<<<<------Fire PHP message
			$query = "UPDATE ".cms_db_prefix()."module_scriptdeploy_groupassignment SET ScriptORDER=? WHERE ScriptID= ? AND GrouptSetID=?";
	
			$result = &$db->Execute($query,array($ScriptORDER,$ScriptID,$Gid));
			$db->sql;
			if(!$result){
			  //echo 'Error: '.mysql_error();
			  $params['message'] = mysql_error();
			  $this->FireDebug('error',mysql_error());//<<<<------Fire PHP message
			}else{
			   $params['message'] = $this->Lang('prefsupdated');
			}
		}
		$params = array('tab_message'=> 'Edited', 'active_tab' => 'script_template','mode'=>'edit','GrouptSet'=>$GrouptSet,'GrouptID'=>$Gid,'group'=>$Gid,'groupt1'=>$Gid);
		$this->Redirect($id, 'editassignment', '', $params);
	}
	


		
	//$scriptSize=mb_strlen($_POST['m1_ScriptIs_input'], '8bit');
	//$scriptSize=strlen(utf8_decode($params['ScriptIs_input']));


	if($params['mode']=='edit'){
			$GroupName=$params['GrouptSet'];
			$ScriptID=$params['ScriptPicker'];
		
			$alldbProfiles = $this->TieAScript('selectGroupsListings',$Gid);

		
			$query = "DELETE sn FROM ".cms_db_prefix()."module_scriptdeploy_groupassignment AS sn WHERE sn.GrouptSetID = ?";
			$result = $db->Execute($query,array($Gid));
			
				$ScriptORDER='';
			 foreach($ScriptID as $key => $SArrayItem){
				foreach($alldbProfiles as $keys => $onedbProfile ){
					$HOLDERScriptID=$keys;
					$HOLDERScriptORDER=$onedbProfile['ScriptORDER'];
					if($HOLDERScriptID==$SArrayItem){
						$ScriptORDER=$HOLDERScriptORDER;
					}else{
						$ScriptORDER='';
					}
				}
				 
				$query = "INSERT INTO ".cms_db_prefix()."module_scriptdeploy_groupassignment (GrouptSetID, ScriptID, ScriptORDER) VALUES ( ?,?,?)";
				$result = &$db->Execute($query,array($Gid,$SArrayItem,$ScriptORDER));
				if(!$result){
				  //echo 'Error: '.mysql_error();
				  $params['message'] = mysql_error();
				}else{
				   $params['message'] = $this->Lang('prefsupdated');
				}			
			}
	}else if($params['mode']=='addScript'){	
		 
		$query = "UPDATE ".cms_db_prefix()."module_scriptdeploy_group AS sdG "
				."INNER join  ".cms_db_prefix()."module_scriptdeploy_scriptoptions so ON sn.ID = so.ID "
				."INNER join  ".cms_db_prefix()."module_scriptdeploy_scriptparts sp ON sn.ID = sp.ID "
				."SET so.Minify=?, sn.ScriptSet=?, so.maxAge=?, so.pathOption=?, so.scriptType=?, sp.ScriptIs=?, so.scriptSize=? WHERE sn.ID = ?";

		$result = &$db->Execute($query,array($Minify,$scriptName,$maxAge,$pathOption,$scriptType,$ScriptIs,$scriptSize,$ScriptID));
		if(!$result){
		  //echo 'Error: '.mysql_error();
		  $params['message'] = mysql_error();
		  $this->FireDebug('error',mysql_error());//<<<<------Fire PHP message
		}else{
		   $params['message'] = $this->Lang('prefsupdated');
		}
		$this->FireDebug('error',$params['mode']);//<<<<------Fire PHP message
	}
	if(isset($params['submitbutton'])||isset($params['Save'])){
		$dirpath=$config['uploads_path']."/lib/SD-temp/";
		$deleted = $this->recursive_rmdir($dirpath);
		$params = array('tab_message'=> 'Edited', 'active_tab' => 'script_template','mode'=>'edit','GrouptSet'=>$GroupName,'GrouptID'=>$Gid,'group'=>$Gid,'groupt1'=>$Gid);
		$this->Redirect($id, 'editassignment', '', $params);
	}

	if($params['mode']=='add'){
		$params = array('tab_message'=> 'BtnADDED', 'active_tab' => 'manualassignment');
	}else{
		$params = array('tab_message'=> 'BtnEDITED', 'active_tab' => 'manualassignment');
	}

		$dirpath=$config['uploads_path']."/lib/SD-temp/";
		$deleted = $this->recursive_rmdir($dirpath);
	$this->Redirect($id, 'defaultadmin', '', $params);
?>
